#include "fmacros.h"

#include <pthread.h>

#include "zlog.h"
#include "zc_defs.h"
#include "buf.h"

static pthread_rwlock_t zlog_env_lock_ex = PTHREAD_RWLOCK_INITIALIZER;

int dzlog_init_ex(const char* config,
                 const char* cname,
                 const char* project_name,
                 const char* program_name)
{
    int rc;

    zc_debug("------zlog_init_ex start------");

    if (project_name)
    {
        setenv("PROJECT_NAME", project_name, 1);
    }

    if (program_name)
    {
        setenv("PROGRAM_NAME", program_name, 1);
    }

    rc = pthread_rwlock_wrlock(&zlog_env_lock_ex);
    if (rc)
    {
        zc_error("pthread_rwlock_wrlock fail, rc[%d]", rc);
        return -1;
    }

    if (!config)
    {
        rc = dzlog_init("/etc/zlog.conf", cname);
    }
    else
    {
        rc = dzlog_init(config, cname);
    }

    if (rc) goto err;

    zc_debug("------zlog_init success end------");
    rc = pthread_rwlock_unlock(&zlog_env_lock_ex);
    if (rc)
    {
        zc_error("pthread_rwlock_unlock fail, rc=[%d]", rc);
        return -1;
    }
    return 0;
err:
    zc_error("------zlog_init_ex fail end------");
    rc = pthread_rwlock_unlock(&zlog_env_lock_ex);
    if (rc)
    {
        zc_error("pthread_rwlock_unlock fail, rc=[%d]", rc);
        return -1;
    }
    return -1;
}
